@@ -6,7 +6,7 @@ use experimental 'smartmatch';
 
 # ABSTRACT: Web::API - A Simple base module to implement almost every RESTful API with just a few lines of configuration
 
-our $VERSION = '2.2.1'; # VERSION
+our $VERSION = '2.2.2'; # VERSION
 
 use LWP::UserAgent;
 use HTTP::Cookies;
@@ -707,12 +707,13 @@ sub format_response {
 
     my $answer;
 
-    # collect response headers
     if ($response) {
+        # collect response headers
         my $response_headers;
         $response_headers->{$_} = $response->header($_)
             foreach ($response->header_field_names);
 
+        # decode content if necessary
         unless ($self->_decoded_response) {
             $self->_decoded_response(
                 eval {
@@ -722,6 +723,7 @@ sub format_response {
             $error ||= $@;
         }
 
+        # search for and expose errors
         $error ||= $self->find_error($self->_decoded_response);
 
         $answer = {
@@ -729,6 +731,7 @@ sub format_response {
             code    => $response->code,
             content => $self->_decoded_response,
             raw     => $response->content,
+            cookies => $self->cookies->get_cookies($self->base_url),
         };
 
         unless ($response->is_success || $response->is_redirect) {
@@ -859,7 +862,7 @@ Web::API - Web::API - A Simple base module to implement almost every RESTful API
 
 =head1 VERSION
 
-version 2.2.1
+version 2.2.2
 
 =head1 SYNOPSIS
 
